==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/LinearContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { LinearContourValueResolverDescription } from "./LinearContourValueResolverDescription";
/**
 * @hidden
 */
export let LinearContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class LinearContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (LinearContourValueResolverDescriptionMetadata.a == null) {
                LinearContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LinearContourValueResolverDescriptionMetadata.c(LinearContourValueResolverDescriptionMetadata.a);
            }
            if (a.k(LinearContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.ab(LinearContourValueResolverDescriptionMetadata.a);
        }
        static c(a) {
            ContourValueResolverDescriptionMetadata.c(a);
            a.item("ValueCount", "Number:int");
        }
        static d(a) {
            LinearContourValueResolverDescriptionMetadata.b(a);
            a.ad("LinearContourValueResolver", () => new LinearContourValueResolverDescription());
            a.ac("LinearContourValueResolver", LinearContourValueResolverDescriptionMetadata.a);
        }
    }
    LinearContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(LinearContourValueResolverDescriptionMetadata, 'LinearContourValueResolverDescriptionMetadata');
    LinearContourValueResolverDescriptionMetadata.a = null;
    return LinearContourValueResolverDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/LinearContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ContourValueResolverDescriptionMetadata } from "./ContourValueResolverDescriptionMetadata";
import { LinearContourValueResolverDescription } from "./LinearContourValueResolverDescription";
/**
 * @hidden
 */
export let LinearContourValueResolverDescriptionMetadata = /*@__PURE__*/ (() => {
    class LinearContourValueResolverDescriptionMetadata extends Base {
        static b(a) {
            if (LinearContourValueResolverDescriptionMetadata.a == null) {
                LinearContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LinearContourValueResolverDescriptionMetadata.c(LinearContourValueResolverDescriptionMetadata.a);
            }
            if (a.k(LinearContourValueResolverDescriptionMetadata.a)) {
                return;
            }
            a.ac(LinearContourValueResolverDescriptionMetadata.a);
        }
        static c(a) {
            ContourValueResolverDescriptionMetadata.c(a);
            a.item("ValueCount", "Number:int");
        }
        static d(a) {
            LinearContourValueResolverDescriptionMetadata.b(a);
            a.ae("LinearContourValueResolver", () => new LinearContourValueResolverDescription());
            a.ad("LinearContourValueResolver", LinearContourValueResolverDescriptionMetadata.a);
        }
    }
    LinearContourValueResolverDescriptionMetadata.$t = /*@__PURE__*/ markType(LinearContourValueResolverDescriptionMetadata, 'LinearContourValueResolverDescriptionMetadata');
    LinearContourValueResolverDescriptionMetadata.a = null;
    return LinearContourValueResolverDescriptionMetadata;
})();
